pub trait Catalog: Catalog + Catalog {
// Provided methods
fn default_input<'a>() -> <Self as Catalog>::Class<'a> { ... }
fn default_menu<'a>() -> <Self as Catalog>::Class<'a> { ... }
}Expand description
The theme catalog of a SuggestionTextInput.
Provided Methods
Sourcefn default_input<'a>() -> <Self as Catalog>::Class<'a>
fn default_input<'a>() -> <Self as Catalog>::Class<'a>
The default class for the text input of the SuggestionTextInput.
The default class for the menu of the SuggestionTextInput.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.